@@ -18,6 +18,7 @@ server_base_data = {
     "serverPut": "{user} {host} {pwd} {port} {locPath} {serPath}",
     "serverGet": "{user} {host} {pwd} {port} {locPath} {serPath}",
     "serverLogin": "{user} {host} {pwd} {port}",
+    "serverLoginSSH": "{user} {host} {port}",
     "serverTbj": "{user} {host} {pwd} {port} {pem}",
 
 }
@@ -28,7 +29,7 @@ class ServerD:
     @staticmethod
     def serverB(s_type, s_data):
         cmd = '{}/serverE/{} {}'.format(file_path, s_type, s_data)
-        print(cmd)
+        # print(cmd)
         os.system(cmd)
 
     def login(self, server_name):
@@ -39,7 +40,10 @@ class ServerD:
         if not login_dict:
             print("{} 不存在".format(server_name))
             exit(1)
+        if not login_dict.get("pwd"):
+            s_type = "serverLoginSSH"
         s_data = server_base_data.get(s_type).format(**login_dict)
+        print(s_data)
         self.serverB(s_type, s_data)
 
     def get(self, server_name, locPath, serPath, root=False):
